Installs the filters and binds them to the reactable
widget and the dataframe presented in the reactable.
define_filters() needs to be called in the server function of any
shiny app using shinyfilter.
define_filters(input, react_id, filters, data)The input object provided as an argument to the server function.
Object ID/input slot of the reactable which the
filters will be linked to.
A named character vector with the column names of the
dataframe that will be filtered. The names of the vector elements
are the object IDs/input slots of the respective selectizeInput()
widgets used as filters.
The (unfiltered) dataframe presented in the reactable.
No return value.
For a full example of a shiny app using shinyfilter please
call up the help for update_filters(). See the
README.md file or the GitHub repo on
https://github.com/jsugarelli/shinyfilter
for a comprehensive shinyfilter tutorial.